@@ -4,7 +4,7 @@
 # See "LICENSE" for further details.
 
 '''
-Project-wide **PEP-agnostic type hint coercers** (i.e., mid-level callables
+Beartype **PEP-agnostic type hint coercers** (i.e., mid-level callables
 *permanently* converting type hints from one format into another, either
 losslessly or in a lossy manner).
 
@@ -24,9 +24,9 @@ This private submodule is *not* intended for importation by downstream callers.
 #iterables, which can *ALWAYS* be safely rewritten to be hashable (e.g.,
 #coercing "callable[[], None]" to "callable[(), None]").
 
-#FIXME: coerce_hint() should also coerce PEP 544-compatible protocols *NOT*
-#decorated by @typing.runtime_checkable to be decorated by that decorator, as
-#such protocols are unusable at runtime. Yes, we should always try something
+#FIXME: [PEP 544] coerce_hint() should also coerce PEP 544-compatible protocols
+#*NOT* decorated by @typing.runtime_checkable to be decorated by that decorator,
+#as such protocols are unusable at runtime. Yes, we should always try something
 #*REALLY* sneaky and clever.
 #
 #Specifically, rather than accept "typing" nonsense verbatim, we could instead:
@@ -59,9 +59,10 @@ from beartype.typing import (
     Union,
 )
 from beartype._cave._cavefast import NotImplementedType
-from beartype._data.datakind import ARG_NAME_RETURN
+from beartype._data.func.datafuncarg import ARG_NAME_RETURN
 from beartype._data.func.datafunc import METHOD_NAMES_DUNDER_BINARY
 from beartype._check.checkcall import BeartypeCall
+from beartype._check.forward.fwdhint import resolve_hint
 from beartype._util.cache.map.utilmapbig import CacheUnboundedStrong
 from beartype._util.hint.utilhinttest import is_hint_uncached
 from beartype._util.hint.pep.proposal.pep484.utilpep484union import (
@@ -71,6 +72,7 @@ from beartype._util.hint.pep.proposal.pep484.utilpep484union import (
 #FIXME: Document mypy-specific coercion in the docstring as well, please.
 def coerce_func_hint_root(
     hint: object,
+    #FIXME: Rename to "pith_name" for orthogonality with everything else.
     arg_name: str,
     bear_call: BeartypeCall,
     exception_prefix: str,
@@ -92,10 +94,10 @@ def coerce_func_hint_root(
     This function *cannot* be meaningfully memoized, since the passed type hint
     is *not* guaranteed to be cached somewhere. Only functions passed cached
     type hints can be meaningfully memoized. Since this high-level function
-    internally defers to unmemoized low-level functions that are ``O(n)`` in
-    ``n`` the size of the inheritance hierarchy of this hint, this function
-    should be called sparingly. See the :mod:`beartype._decor._cache.cachehint`
-    submodule for further details.
+    internally defers to unmemoized low-level functions that are :math:`O(n)`
+    for :math:``n` the size of the inheritance hierarchy of this hint, this
+    function should be called sparingly. See the
+    :mod:`beartype._decor.cache.cachehint` submodule for further details.
 
     Parameters
     ----------
@@ -122,10 +124,25 @@ def coerce_func_hint_root(
           type hint coerced from this hint.
         * Else, this hint as is unmodified.
     '''
-    assert isinstance(arg_name, str), f'{arg_name} not string.'
+    assert isinstance(arg_name, str), f'{repr(arg_name)} not string.'
     assert bear_call.__class__ is BeartypeCall, (
         f'{repr(bear_call)} not @beartype call.')
 
+    # ..................{ FORWARD REFERENCE                  }..................
+    # If this hint is stringified (e.g., as a PEP 484- or 563-compliant forward
+    # reference), resolve this hint to the non-string hint to which this hint
+    # refers *BEFORE* performing any subsequent logic with this hint -- *ALL* of
+    # which assumes this hint to be a non-string hint.
+    if isinstance(hint, str):
+        hint = resolve_hint(
+            hint=hint,
+            bear_call=bear_call,
+            exception_prefix=exception_prefix,
+        )
+    # Else, this hint is *NOT* stringified.
+    #
+    # In either case, this hint is guaranteed to now be a non-string hint.
+
     # ..................{ MYPY                               }..................
     # If...
     if (
@@ -212,7 +229,7 @@ def coerce_hint_root(hint: object, exception_prefix: str) -> object:
     type hints can be meaningfully memoized. Since this high-level function
     internally defers to unmemoized low-level functions that are ``O(n)`` for
     ``n`` the size of the inheritance hierarchy of this hint, this function
-    should be called sparingly. See the :mod:`beartype._decor._cache.cachehint`
+    should be called sparingly. See the :mod:`beartype._decor.cache.cachehint`
     submodule for further details.
 
     Parameters
