@@ -26,7 +26,7 @@ from beartype._data.hint.pep.sign.datapepsignset import (
     HINT_SIGNS_SUPPORTED,
     HINT_SIGNS_TYPE_MIMIC,
 )
-from beartype._data.mod.datamodtyping import TYPING_MODULE_NAMES
+from beartype._data.module.datamodtyping import TYPING_MODULE_NAMES
 from beartype._util.cache.utilcachecall import callable_cached
 from beartype._util.hint.pep.proposal.pep484.utilpep484 import (
     is_hint_pep484_ignorable_or_none)
@@ -34,7 +34,7 @@ from beartype._util.hint.pep.proposal.utilpep544 import (
     is_hint_pep544_ignorable_or_none)
 from beartype._util.hint.pep.proposal.utilpep593 import (
     is_hint_pep593_ignorable_or_none)
-from beartype._util.mod.utilmodget import get_object_module_name_or_none
+from beartype._util.module.utilmodget import get_object_module_name_or_none
 from beartype._util.utilobject import get_object_type_unless_type
 from warnings import warn
 
@@ -178,7 +178,7 @@ def die_if_hint_pep_unsupported(
     BeartypeDecorHintPep484Exception
         If this object is the PEP-compliant :attr:`typing.NoReturn` type hint,
         which is contextually valid in only a single use case and thus
-        supported externally by the :mod:`beartype._decor._wrap.wrapmain`
+        supported externally by the :mod:`beartype._decor.wrap.wrapmain`
         submodule rather than with general-purpose automation.
     '''
 
