@@ -4,13 +4,9 @@
 # See "LICENSE" for further details.
 
 '''
-**Beartype all-at-once low-level package name cache.**
-
-This private submodule caches package names on behalf of the higher-level
-:func:`beartype.claw.beartype_package` function. Beartype import
-path hooks internally created by that function subsequently lookup these package
-names from this cache when deciding whether or not (and how) to decorate a
-submodule being imported with :func:`beartype.beartype`.
+Beartype **import hook managers** (i.e., lower-level private-facing functions
+internally driving the higher-level public facing import hooks exported by the
+:mod:`beartype.claw._clawmain` submodule).
 
 This private submodule is *not* intended for importation by downstream callers.
 '''
@@ -19,24 +15,25 @@ This private submodule is *not* intended for importation by downstream callers.
 from beartype.claw._pkg.clawpkgenum import BeartypeClawCoverage
 from beartype.claw._pkg.clawpkgtrie import (
     PackagesTrie,
-    # is_packages_trie,
     iter_packages_trie,
-    packages_trie,
-    packages_trie_lock,
     remove_beartype_pathhook_unless_packages_trie,
 )
+from beartype.claw._pkg._clawpkgmake import (
+    make_conf_hookable,
+    make_package_names_from_args,
+)
 from beartype.claw._importlib.clawimppath import (
     add_beartype_pathhook,
     # remove_beartype_pathhook,
 )
-from beartype.roar import BeartypeClawRegistrationException
+from beartype.roar import (
+    BeartypeClawHookException,
+)
 from beartype.typing import (
     Iterable,
     Optional,
 )
 from beartype._conf.confcls import BeartypeConf
-from beartype._util.text.utiltextident import is_identifier
-from collections.abc import Iterable as IterableABC
 
 # ....................{ (UN)HOOKERS                        }....................
 #FIXME: Unit test us up, please.
@@ -89,7 +86,7 @@ def hook_packages(
 
     Raises
     ----------
-    BeartypeClawRegistrationException
+    BeartypeClawHookException
         If either:
 
         * The passed ``package_names`` parameter is either:
@@ -116,8 +113,19 @@ def hook_packages(
         this function with respect to inscrutable :mod:`importlib` machinery.
     '''
 
+    # Avoid circular import dependencies.
+    from beartype.claw._clawstate import (
+        claw_lock,
+        claw_state,
+    )
+
+    # Replace this beartype configuration (which is typically unsuitable for
+    # usage in import hooks) with a new beartype configuration suitable for
+    # usage in import hooks.
+    conf = make_conf_hookable(conf)
+
     # Iterable of the passed fully-qualified names of all packages to be hooked.
-    package_names = _get_package_names_from_args(
+    package_names = make_package_names_from_args(
         claw_coverage=claw_coverage,
         conf=conf,
         package_name=package_name,
@@ -125,25 +133,25 @@ def hook_packages(
     )
 
     # With a submodule-specific thread-safe reentrant lock...
-    with packages_trie_lock:
+    with claw_lock:
         # If the caller requested all-packages coverage...
         if claw_coverage is BeartypeClawCoverage.PACKAGES_ALL:
             # Beartype configuration currently associated with *ALL* packages by
             # a prior call to this function if any *OR* "None" (i.e., if this
             # function has yet to be called under this Python interpreter).
-            conf_curr = packages_trie.conf_if_hooked
+            conf_curr = claw_state.packages_trie.conf_if_hooked
 
             # If the higher-level beartype_all() function (calling this
             # lower-level adder) has yet to be called under this interpreter,
             # associate this configuration with *ALL* packages.
             if conf_curr is None:
-                packages_trie.conf_if_hooked = conf
+                claw_state.packages_trie.conf_if_hooked = conf
             # Else, beartype_all() was already called under this interpreter.
             #
             # If the caller passed a different configuration to that prior call
             # than that passed to this current call, raise an exception.
             elif conf_curr != conf:
-                raise BeartypeClawRegistrationException(
+                raise BeartypeClawHookException(
                     f'beartype_all() previously passed '
                     f'conflicting beartype configuration:\n'
                     f'\t----------( OLD "conf" PARAMETER )----------\n'
@@ -168,7 +176,7 @@ def hook_packages(
                 # Current subtrie of the global package trie describing the
                 # currently iterated basename of this package, initialized to
                 # the global trie configuring all top-level packages.
-                subpackages_trie = packages_trie
+                subpackages_trie = claw_state.packages_trie
 
                 # For each unqualified basename comprising the directed path from
                 # the root parent package of that package to that package...
@@ -203,6 +211,7 @@ def hook_packages(
                 # "subpackages_trie" to at least one subtrie of the global package
                 # trie. Moreover, that subtrie is guaranteed to describe the current
                 # (sub)package being registered.
+                # print(f'Hooked package "{package_name}" subpackage trie {repr(subpackages_trie)}...')
 
                 # Beartype configuration currently associated with that package by a
                 # prior call to this function if any *OR* "None" (i.e., if that
@@ -220,7 +229,7 @@ def hook_packages(
                 # If the caller passed a different configuration to that prior call
                 # than that passed to this current call, raise an exception.
                 elif conf_curr != conf:
-                    raise BeartypeClawRegistrationException(
+                    raise BeartypeClawHookException(
                         f'Beartype import hook '
                         f'(e.g., beartype.claw.beartype_*() function) '
                         f'previously passed '
@@ -273,9 +282,20 @@ def unhook_packages(
         Further details.
     '''
 
+    # Avoid circular import dependencies.
+    from beartype.claw._clawstate import (
+        claw_lock,
+        claw_state,
+    )
+
+    # Replace this beartype configuration (which is typically unsuitable for
+    # usage in import hooks) with a new beartype configuration suitable for
+    # usage in import hooks.
+    conf = make_conf_hookable(conf)
+
     # Iterable of the passed fully-qualified names of all packages to be
     # unhooked.
-    package_names = _get_package_names_from_args(
+    package_names = make_package_names_from_args(
         claw_coverage=claw_coverage,
         conf=conf,
         package_name=package_name,
@@ -283,12 +303,12 @@ def unhook_packages(
     )
 
     # With a submodule-specific thread-safe reentrant lock...
-    with packages_trie_lock:
+    with claw_lock:
         # If the caller requested all-packages coverage...
         if claw_coverage is BeartypeClawCoverage.PACKAGES_ALL:
             # Unhook the beartype configuration previously associated with *ALL*
             # packages by a prior call to the beartype_all() function.
-            packages_trie.conf_if_hooked = None
+            claw_state.packages_trie.conf_if_hooked = None
         # Else, the caller requested coverage over a subset of packages. In this
         # case...
         else:
@@ -347,7 +367,7 @@ def unhook_packages(
 
                         # Delete this child sub-subpackages trie from this
                         # parent subpackages trie.
-                        del subpackages_trie[subsubpackage_basename]
+                        del subpackages_trie[subsubpackage_basename]  # pyright: ignore[reportGeneralTypeIssues]
                     # Else, this is the first iteration of this loop.
 
                     # Treat this parent subpackages trie as the child
@@ -363,115 +383,3 @@ def unhook_packages(
         # * Defer doing so until *AFTER* the above iteration has successfully
         #   unregistered the desired packages with our global trie.
         remove_beartype_pathhook_unless_packages_trie()
-
-# ....................{ PRIVATE ~ checkers                 }....................
-#FIXME: Unit test us up, please.
-def _get_package_names_from_args(
-    # Keyword-only arguments.
-    *,
-
-    # Mandatory keyword-only arguments.
-    claw_coverage: BeartypeClawCoverage,
-    conf: BeartypeConf,
-
-    # Optional keyword-only arguments.
-    package_name: Optional[str] = None,
-    package_names: Optional[Iterable[str]] = None,
-) -> Optional[Iterable[str]]:
-    '''
-    Validate all parameters passed by the caller to the parent
-    :func:`.hook_packages` or :func:`.unhook_packages` function.
-
-    Returns
-    ----------
-    Optional[Iterable[str]]
-        Iterable of the fully-qualified names of one or more packages to be
-        either hooked or unhooked by the parent call.
-
-    See Also
-    ----------
-    :func:`.hook_packages`
-        Further details.
-    '''
-
-    # If the "conf" parameter is *NOT* a configuration, raise an exception.
-    if not isinstance(conf, BeartypeConf):
-        raise BeartypeClawRegistrationException(
-            f'Beartype configuration {repr(conf)} invalid (i.e., not '
-            f'"beartype.BeartypeConf" instance).'
-        )
-    # Else, the "conf" parameter is a configuration.
-
-    # If the caller requested all-packages coverage...
-    if claw_coverage is BeartypeClawCoverage.PACKAGES_ALL:
-        # If the caller improperly passed a package name despite requesting
-        # all-packages coverage, raise an exception.
-        if package_name is not None:
-            raise BeartypeClawRegistrationException(
-                f'Coverage {repr(BeartypeClawCoverage.PACKAGES_ALL)} '
-                f'but package name {repr(package_name)} passed.'
-            )
-        # Else, the caller properly passed *NO* package name.
-        #
-        # If the caller improperly passed multiple package names despite
-        # requesting all-packages coverage, raise an exception.
-        elif package_names is not None:
-            raise BeartypeClawRegistrationException(
-                f'Coverage {repr(BeartypeClawCoverage.PACKAGES_ALL)} '
-                f'but package names {repr(package_names)} passed.'
-            )
-        # Else, the caller properly passed *NO* package names.
-    # Else, the caller did *NOT* request all-packages coverage. In this case,
-    # the caller requested coverage over only a subset of packages.
-    else:
-        # If the caller requested mono-package coverage...
-        if claw_coverage is BeartypeClawCoverage.PACKAGES_ONE:
-            # If the caller improperly passed *NO* package name despite
-            # requesting mono-package coverage, raise an exception.
-            if package_name is None:
-                raise BeartypeClawRegistrationException(
-                    f'beartype_package() '
-                    f'package name {repr(package_name)} invalid.'
-                )
-            # Else, the caller properly passed a package name.
-
-            # Wrap this package name in a 1-tuple containing only this name.
-            # Doing so unifies logic below.
-            package_names = (package_name,)
-        # Else, the caller requested multi-package coverage.
-        # elif coverage is BeartypeClawCoverage.PACKAGES_MANY:
-
-        # If this package names is *NOT* iterable, raise an exception.
-        if not isinstance(package_names, IterableABC):
-            raise BeartypeClawRegistrationException(
-                f'beartype_packages() '
-                f'package names {repr(package_name)} not iterable.'
-            )
-        # Else, this package names is iterable.
-        #
-        # If *NO* package names were passed, raise an exception.
-        elif not package_names:
-            raise BeartypeClawRegistrationException(
-                'beartype_packages() package names empty.')
-        # Else, one or more package names were passed.
-
-        # For each such package name...
-        for package_name in package_names:
-            # If this package name is *NOT* a string, raise an exception.
-            if not isinstance(package_name, str):
-                raise BeartypeClawRegistrationException(
-                    f'Package name {repr(package_name)} not string.')
-            # Else, this package name is a string.
-            #
-            # If this package name is *NOT* a valid Python identifier, raise an
-            # exception.
-            elif not is_identifier(package_name):
-                raise BeartypeClawRegistrationException(
-                    f'Package name {repr(package_name)} invalid '
-                    f'(i.e., not "."-delimited Python identifier).'
-                )
-            # Else, this package name is a valid Python identifier.
-
-    # Return the iterable of the fully-qualified names of one or more packages
-    # to be either hooked or unhooked by the parent call.
-    return package_names
