@@ -4,7 +4,7 @@
 # See "LICENSE" for further details.
 
 '''
-Beartype :pep:`563` **support** (i.e., low-level functions resolving stringified
+Beartype :pep:`563` support (i.e., public callables resolving stringified
 :pep:`563`-compliant type hints implicitly postponed by the active Python
 interpreter via a ``from __future__ import annotations`` statement at the head
 of the external user-defined module currently being introspected).
@@ -20,7 +20,6 @@ This private submodule is *not* intended for importation by downstream callers.
 #Python interpreter targets Python >= 3.10 *AND* the passed callable is nested.
 
 # ....................{ IMPORTS                            }....................
-import __future__
 from beartype.roar import BeartypePep563Exception
 from beartype._check.checkcall import make_beartype_call
 from beartype._check.forward.fwdhint import resolve_hint
@@ -31,7 +30,7 @@ from beartype._conf.confcls import (
 from beartype._data.hint.datahinttyping import TypeStack
 from beartype._util.cache.pool.utilcachepoolobjecttyped import (
     release_object_typed)
-from beartype._util.func.utilfunctest import die_unless_func_python
+from beartype._util.func.utilfuncget import get_func_annotations
 from collections.abc import Callable
 
 # ....................{ RESOLVERS                          }....................
@@ -142,32 +141,36 @@ def resolve_pep563(
     BeartypePep563Exception
         If either:
 
-        * That callable is *not* pure-Python (e.g., is C-based).
+        * That callable is *not* a pure-Python callable (e.g., is C-based).
         * Evaluating a postponed annotation on that callable raises an exception
           (e.g., due to that annotation referring to local state inaccessible in
           this deferred context).
     '''
 
-    # ..................{ VALIDATION                         }..................
-    # If that callable is *NOT* pure-Python, raise an exception.
-    die_unless_func_python(func=func, exception_cls=BeartypePep563Exception)
-    # Else, that callable is pure-Python.
-
     # ..................{ NOOP                               }..................
     # Dictionary to be returned, mapping from the name of each annotated
     # parameter and return of the passed callable to the non-string type hint
-    # resolved from the string type hint annotating that parameter or return,
-    # initialized to a shallow copy of that dictionary.
+    # resolved from the string type hint annotating that parameter or return --
+    # raising an exception if that callable is *NOT* a pure-Python callable.
     #
     # Note that the "func.__annotations__" dictionary *CANNOT* be safely
     # directly assigned to below, as the loop performing that assignment below
     # necessarily iterates over that dictionary. As with most languages, Python
     # containers cannot be safely mutated while being iterated.
-    arg_name_to_hint = func.__annotations__
+    arg_name_to_hint = get_func_annotations(
+        func=func,
+        exception_cls=BeartypePep563Exception,
+        exception_prefix='Callable ',
+    )
 
-    # If the passed callable was *NOT* subject to PEP 563-compliant postponement
-    # of type hints under the standard "from __future__ import annotations"
-    # import, silently reduce to a noop.
+    # If that callable is unannotated, silently reduce to a noop.
+    if not arg_name_to_hint:
+        return
+    # Else, that callable is annotated by one or more type hints.
+
+    # If that callable was *NOT* subject to PEP 563-compliant postponement of
+    # type hints under the standard "from __future__ import annotations" import,
+    # silently reduce to a noop.
     #
     # Note that there exist numerous means of detecting PEP 563. This approach:
     # * Is the least efficient, requiring O(n) iteration for n the number of
@@ -284,16 +287,42 @@ def resolve_pep563(
     # Release this beartype call metadata back to its object pool.
     release_object_typed(bear_call)
 
-    # Atomically (i.e., all-at-once) replace that callable's postponed
-    # annotations with these resolved annotations for safety and efficiency.
+    # Attempt to...
+    try:
+        # Atomically (i.e., all-at-once) replace that callable's postponed
+        # annotations with these resolved annotations for safety and efficiency.
+        #
+        # While the @beartype decorator goes to great lengths to preserve the
+        # originating "__annotations__" dictionary as is, PEP 563 is
+        # sufficiently expensive, non-trivial, and general-purpose to implement
+        # that generally resolving postponed annotations for downstream
+        # third-party callers is justified. Everyone benefits from replacing
+        # useless postponed annotations with useful real annotations; so, do so.
+        func.__annotations__ = arg_name_to_hint
+    # If doing so fails with an exception resembling the following, then that
+    # callable is *NOT* a pure-Python callable but rather a C-based decorator
+    # object of some sort (e.g., class, property, or static method descriptor):
+    #     AttributeError: 'method' object has no attribute '__annotations__'
     #
-    # While the @beartype decorator goes to great lengths to preserve the
-    # originating "__annotations__" dictionary as is, PEP 563 is sufficiently
-    # expensive, non-trivial, and general-purpose to implement that generally
-    # resolving postponed annotations for downstream third-party callers is
-    # justified. Everyone benefits from replacing useless postponed annotations
-    # with useful real annotations; so, we do so.
-    func.__annotations__ = arg_name_to_hint
+    # C-based decorator objects define a read-only "__annotations__" dunder
+    # attribute that proxies an original writeable "__annotations__" dunder
+    # attribute of the pure-Python callables they originally decorated. Ergo,
+    # detecting this edge case is non-trivial and most most easily deferred to
+    # this late time. While non-ideal, simplicity >>>> idealism in this case.
+    except AttributeError:
+        # For the name of each annotated parameter and return of that callable
+        # and the destringified type hint annotating this parameter or return,
+        # overwrite the stringified type hint originally annotating this
+        # parameter or return with this destringified type hint.
+        #
+        # Note that:
+        # * The above assignment is an efficient O(1) operation and thus
+        #   intentionally performed first.
+        # * This iteration-based assignment is an inefficient O(n) operation
+        #   (where "n" is the number of annotated parameters and returns of that
+        #   callable) and thus intentionally performed last here.
+        for arg_name, arg_hint in arg_name_to_hint.items():
+            func.__annotations__[arg_name] = arg_hint
 
     # print(
     #     f'{func.__name__}() PEP 563-postponed annotations resolved:'
@@ -301,13 +330,6 @@ def resolve_pep563(
     #     f'\n\t------[ RESOLVED  ]------\n\t{func_hints_resolved}'
     # )
 
-# ....................{ PRIVATE ~ constants                }....................
-_FUTURE_ANNOTATIONS = __future__.annotations
-'''
-:obj:`__future__.annotations` object, globalized as a private constant of this
-submodule to negligibly optimize repeated lookups of this object.
-'''
-
 # ....................{ PRIVATE ~ resolvers                }....................
 #FIXME: We currently no longer require this. See above for further commentary.
 # from beartype.roar import BeartypeDecorHintPepException
