@@ -52,6 +52,8 @@ from beartype.roar._roarexc import (
     BeartypeClawImportAstException as BeartypeClawImportAstException,
     BeartypeClawImportConfException as BeartypeClawImportConfException,
     BeartypeConfException as BeartypeConfException,
+    BeartypeConfParamException as BeartypeConfParamException,
+    BeartypeConfShellVarException as BeartypeConfShellVarException,
     BeartypeDoorException as BeartypeDoorException,
     BeartypeDoorNonpepException as BeartypeDoorNonpepException,
     BeartypeDoorPepException as BeartypeDoorPepException,
@@ -103,6 +105,8 @@ from beartype.roar._roarwarn import (
     BeartypeWarning as BeartypeWarning,
     BeartypeClawWarning as BeartypeClawWarning,
     BeartypeClawDecorWarning as BeartypeClawDecorWarning,
+    BeartypeConfWarning as BeartypeConfWarning,
+    BeartypeConfShellVarWarning as BeartypeConfShellVarWarning,
     BeartypeDecorHintWarning as BeartypeDecorHintWarning,
     # BeartypeDecorHintForwardRefWarning as BeartypeDecorHintForwardRefWarning,
     BeartypeDecorHintPepWarning as BeartypeDecorHintPepWarning,
@@ -154,7 +158,7 @@ def __getattr__(attr_deprecated_name: str) -> object:
     '''
 
     # Isolate imports to avoid polluting the module namespace.
-    from beartype._util.mod.utilmoddeprecate import deprecate_module_attr
+    from beartype._util.module.utilmoddeprecate import deprecate_module_attr
 
     # Return the value of this deprecated attribute and emit a warning.
     return deprecate_module_attr(
